var LinkedList = /** @class */ (function () {
    function LinkedList() {
        Object.defineProperty(this, "first", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "length", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.first = null;
        this.length = 0;
    }
    Object.defineProperty(LinkedList.prototype, "push", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (v) {
            this.first = { value: v, next: this.first };
            this.length++;
        }
    });
    Object.defineProperty(LinkedList.prototype, "unshift", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function () {
            if (this.length === 0) {
                return;
            }
            else {
                var lastnode = this.first;
                var bforelast = lastnode;
                while (lastnode.next !== null) {
                    bforelast = lastnode;
                    lastnode = lastnode.next;
                }
                if (bforelast === this.first) {
                    // bforelast is equal to this.first in case this list had a length of
                    // 1 before calling unshift
                    this.first = null;
                }
                bforelast.next = null;
                this.length--;
                return lastnode.value;
            }
        }
    });
    return LinkedList;
}());
var OrderedMap = /** @class */ (function () {
    function OrderedMap() {
        Object.defineProperty(this, "map", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "order", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.map = new Map();
        this.order = new LinkedList();
    }
    Object.defineProperty(OrderedMap.prototype, "length", {
        get: function () {
            return this.order.length;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(OrderedMap.prototype, "has", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (key) {
            return this.map.has(key);
        }
    });
    Object.defineProperty(OrderedMap.prototype, "get", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (key) {
            return this.map.get(key);
        }
    });
    Object.defineProperty(OrderedMap.prototype, "set", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (key, value) {
            if (this.has(key)) {
                // in case key already exists we just update associated value
                this.map.set(key, value);
                return;
            }
            this.map.set(key, value);
            this.order.push(key);
        }
    });
    Object.defineProperty(OrderedMap.prototype, "unshift", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function () {
            var oldestkey = this.order.unshift();
            if (oldestkey !== undefined) {
                this.map.delete(oldestkey);
            }
        }
    });
    return OrderedMap;
}());
var Cache = /** @class */ (function () {
    function Cache(maxsize) {
        Object.defineProperty(this, "map", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "maxsize", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.map = new OrderedMap();
        this.maxsize = maxsize;
    }
    Object.defineProperty(Cache.prototype, "has", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (key) {
            return this.map.has(key);
        }
    });
    Object.defineProperty(Cache.prototype, "get", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (key) {
            return this.map.get(key);
        }
    });
    Object.defineProperty(Cache.prototype, "length", {
        get: function () {
            return this.map.length;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Cache.prototype, "set", {
        enumerable: false,
        configurable: true,
        writable: true,
        value: function (key, value) {
            this.map.set(key, value);
            if (this.map.length > this.maxsize) {
                this.map.unshift();
            }
        }
    });
    return Cache;
}());
function memoize(func, maxsize) {
    if (maxsize === void 0) { maxsize = 50; }
    // memoize function `func`. `func` should be a function with arity of 1
    var memory = new Cache(maxsize);
    return function (arg1) {
        if (memory.has(arg1)) {
            return memory.get(arg1);
        }
        else {
            var result = func(arg1);
            memory.set(arg1, result);
            return result;
        }
    };
}

export { Cache, LinkedList, memoize };
